@@ -14,6 +14,7 @@ from cloud_governance.gitleaks.gitleaks import GitLeaks
 from cloud_governance.main.es_uploader import ESUploader
 from cloud_governance.common.aws.s3.s3_operations import S3Operations
 from cloud_governance.zombie_cluster.validate_zombies import ValidateZombies
+from cloud_governance.zombie_non_cluster.run_zombie_non_cluster_resources import zombie_non_cluster_resource
 
 # env tests
 # os.environ['AWS_DEFAULT_REGION'] = 'us-east-2'
@@ -116,13 +117,16 @@ def run_policy(account: str, policy: str, region: str, dry_run: str):
         end_date = os.environ.get('end_date', '')
         granularity = os.environ.get('granularity', '')
         file_name = os.environ.get('file_name', '')
+        account = os.environ.get('account', '')
+        if account:
+            account = account.upper()
         cost_explorer_tags = literal_eval(os.environ.get('cost_explorer_tags', {}))
         if granularity and cost_metric:
             run_cost_explorer = GenerateCostExplorerReport(cost_tags=cost_explorer_tags, es_host=es_host, es_port=es_port, es_index=es_index, cost_metric=cost_metric, file_name=file_name,
-                                                           start_date=start_date, end_date=end_date, granularity=granularity)
+                                                           start_date=start_date, end_date=end_date, granularity=granularity, account=account)
         else:
             run_cost_explorer = GenerateCostExplorerReport(cost_tags=cost_explorer_tags, es_host=es_host, es_port=es_port, es_index=es_index, file_name=file_name,
-                                                           start_date=start_date, end_date=end_date)
+                                                           start_date=start_date, end_date=end_date, account=account)
         run_cost_explorer.upload_tags_cost_to_elastic_search()
     elif policy == 'validate_cluster':
         file_path = os.environ.get('file_path', '')
@@ -148,6 +152,8 @@ def run_policy(account: str, policy: str, region: str, dry_run: str):
         if remove_keys:
             remove_keys = literal_eval(remove_keys)
         tag_iam_user(user_tag_operation=user_tag_operation, file_name=file_name, remove_keys=remove_keys, username=username)
+    elif policy == 'zombie_non_cluster_resource':
+        zombie_non_cluster_resource(dry_run=dry_run, region=region)
     elif policy == 'zombie_cluster_resource':
         policy_output = os.environ.get('policy_output', '')
         resource = os.environ.get('resource', '')
